require 'uu/os/rest/dto'

module UU
  module AppLog
    module ApplicationLog

      # DTO containing changed attributes of a existing application log.
      class ApplicationLogSetAttributes < UU::OS::REST::DTO

        # URI of the application log.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # URI of the application.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uu_app_uri

        # Code of the application log. The code must be unique in the
        # given territory, otherwise the set attributes command fails.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Name of the new application log. When nil is set, the name is taken from the
        # meta artifact tName. When the meta artifact does not define a tName,
        # the create command fails.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Description of the new application log. When nil is set, the description is
        # taken from the meta artifact tDescription. When the meta artifact does
        # not define a tDescription, it is left empty.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # Severity (value from {UU::AppLog::ApplicationLog::Severity}) of records to
        # store in the application log. If severity of a particular application log
        # record is equal or higher than this severity, the record is stored, otherwise
        # it is thrown away.
        # @param [String]
        # @return [String]
        attr_accessor :logging_severity

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def uu_app_uri
          attributes[:uuAppURI]
        end

        def uu_app_uri=(val)
          if val
            attributes[:uuAppURI] = UU::OS::UESURI.new(val)
          else
            attributes[:uuAppURI] = nil
          end
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def logging_severity
          attributes[:loggingSeverity]
        end

        def logging_severity=(val)
          if val
            attributes[:loggingSeverity] = val # TODO Convert into an instance of Severity
          else
            attributes[:loggingSeverity] = nil
          end
        end

      end
    end
  end
end

